/* 
 * Metronome session interface
 *
 * This file is part of GTick
 * 
 *
 * Copyright (c) 1999, Alex Roberts
 * Copyright (c) 2003, Roland Stigge <stigge@antcom.de>
 *
 * GTick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GTick is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GTick; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
 
#ifndef METRO_H
#define METRO_H

/* GTK+ headers */
#include <gtk/gtk.h>

/* own headers */
#include "options.h"

typedef enum state_t {
  STATE_IDLE,     /* Metronome off */
  STATE_RUNNING,  /* Metronome on  */
  
  STATE_NUMBER
} state_t;

typedef struct state_data_t {
  char* state;
  char* toggle_label;
} state_data_t;

/*
 * the main metro object
 */
typedef struct metro_t {
  GtkWidget* window;

  GtkWidget *btn0;
  GtkWidget *btn24;
  GtkWidget *btn34;
  GtkWidget *btn44;
  GtkWidget *btnother;
  GtkWidget *meterspinbutton;
  	
  GtkWidget* togglebutton_label;
  GtkWidget* scale;
  GtkObject* adjustment;
  GtkObject* vAdj;
  GtkWidget* vol;

  GtkWidget* statusbar;
  guint status_context;

  options_t* options;         /* structure with all the handled rc options */

  int state; /* metronome active flag */
  gint meter;       /* meter mode */
  double frequency; /* ticking frequency in Hz */
  int cyclepos;     /* current position in buffer */

  /* dsp related */
  
  /* OSS output data */
  int dspfd;        /* file descriptor */
  int fragmentsize; /* fragment size */
  int fragstotal;   /* number of fragments in DSP buffer */
  int channels;     /* number of channels */
  int rate;         /* number of frames per second in Hz */
  int samplesize;   /* number of bits per item (usually 8 or 16) */
  int format;

  guint sound_event_id;     /* unique id for gtk event */
  unsigned char* fragment;
  
  unsigned char* tickdata0; /* raw sample bytes for single tick */
  int td0_size;  /* length in bytes */
  unsigned char* tickdata1; /* raw sample bytes for first tick */
  int td1_size;
  unsigned char* tickdata2; /* sample bytes for other ticks */
  int td2_size;

  unsigned char* silence; /* size = channels * samplesize / 8 */

} metro_t;

metro_t* metro_new(void);
void metro_delete(metro_t* metro);

#endif /* METRO_H */

